========================
``psyclone.psyad.utils``
========================

.. automodule:: psyclone.psyad.utils

   .. contents::
      :local:

.. currentmodule:: psyclone.psyad.utils


Functions
=========

- :py:func:`node_is_active`:
  Determines whether this node contains variables that are active.

- :py:func:`node_is_passive`:
  Determines whether this node contains only variables that are

- :py:func:`negate_expr`:
  Takes a PSyIR expression and negates it by multiplying it by minus


.. autofunction:: node_is_active

.. autofunction:: node_is_passive

.. autofunction:: negate_expr
